# -*- coding: utf-8 -*-

from upload.node.node import Node, QueueInserterConfig, QueueParameters, UsersConverterParameters
import tempfile
import sys
from common import config, logger, macros, registry
from common.cashconvertersconfig import CashConvertersConfig
from upload.node.convertergetter import getConverterByName

reg = registry.Registry()
log = logger.getUploadLogger("main")
badDictsDirectory = '%s/exchangers/badDicts' % tempfile.gettempdir()

shopCode = str(reg.shopcode())
cashCode = str(reg.cashcode())


def readStandartParams(section):
    flags = [ macros.applyMacros(fl.strip(), log, shopcode=shopCode, cashcode=cashCode) for fl in config.getString(section, 'flags', '/tmp/dict/aif/pos*.flz').split(',') ]
    data = [ macros.applyMacros(d.strip(), log, shopcode=shopCode, cashcode=cashCode) for d in config.getString(section, 'data', '/tmp/dict/aif/pos*.aif').split(',') ]
    errorDest = macros.applyMacros(config.getString(section, 'errorDest', '').strip(), log, shopcode=shopCode, cashcode=cashCode)
    return flags, data, errorDest


def getConverter(converterName):
    section = 'upload.converter.%s' % converterName
    flags, data, errorDest = readStandartParams(section)

    if converterName == 'users':
        return UsersConverterParameters(flags=flags, data=data, errorDest=errorDest)

    convertersConfig = CashConvertersConfig(config, section)
    return getConverterByName(converterName=converterName, convertersConfig=convertersConfig, flags=flags, data=data, errorDest=errorDest)


def getNodes():
    log.info(u"Получение ноды")

    if not shopCode or shopCode == '':
        log.error(u"Ошибка получения кода кассы из %s" % reg.path)
        sys.exit(1)

    fileQueueRoot = config.getString('FILEQUEUE', 'fileQueueRoot', '/linuxcash/cash/data/queues')
    queueChunkSize = config.getInt('FILEQUEUE', 'queueChunkSize', 25000)

    badDictsDirectory = macros.applyMacros(config.getString('UPLOAD', 'badDictsDirectory', '/linuxcash/cash/data/backup/badDicts').strip(), log, shopcode=shopCode, cashcode=cashCode)
    convertersInConf = config.getString('UPLOAD', 'converter', 'aif').split(',')
    converters = []
    for converterName in convertersInConf:
        converterName = converterName.strip().lower()
        converter = getConverter(converterName)
        if converter:
            converters.append(converter)
            log.info(u'Конвертер - \'%s\'' % converterName)
            log.info(u'Файлы данных - \'%s\'' % converter.data)
            log.info(u'Файлы флагов - \'%s\'' % converter.flags)
            log.info(u'Файл информации об ошибках - \'%s\'' % converter.errorDest)

    nodes = [Node(id=shopCode,
                      backup_dir=macros.applyMacros(config.getString('UPLOAD', 'backupDir', '/linuxcash/cash/data/backup/dicts'), log, shopcode=shopCode, cashcode=cashCode),
                      converters=converters,
                      pack_size=queueChunkSize,
                      inserter=QueueInserterConfig(queue=QueueParameters(fileQueueRoot, queueChunkSize, 'artix.loaddict.cash')),
                      badDictsDirectory=badDictsDirectory)]
    log.info(u"Получение ноды завершено")
    return nodes


def reInit():
    """
    Используется только для ТЕСТОВ
    """
    global shopCode
    global cashCode
    reg = registry.Registry()
    shopCode = str(reg.shopcode())
    cashCode = str(reg.cashcode())
