# -*- coding: utf-8 -*-
import sys

from upload.node.node import AifConverterParameters, SmagConverterParameters, \
    SmagUkm4ConverterParameters, OracleConverterParameters, ShtrihConverterParameters, \
    AtolConverterParameters, CrystalConverterParameters, SapConverterParameters, Cif1ConverterParameters, \
    SmagXmlConverterParameters

def getConverterByName(converterName, convertersConfig, flags, data, errorDest=None, backupDir=None):
    params = {'flags': flags, 'data': data, 'errorDest': errorDest, 'backup_dir': backupDir}
    if converterName in ['aif', 'ARTIXINTERCHANGE']:
        params['hotKeyByBarcode'] = convertersConfig.getBool('hotKeyByBarcode', False)
        params['checkMatchFileNames'] = convertersConfig.getBool('checkMatchFileNames', False)
        return AifConverterParameters(**params)
    if converterName in ['shtrih', 'SHTRIHM']:
        params['delimiter'] = convertersConfig.getString('delimiter', ';')
        params['cashierName'] = convertersConfig.getBool('cashierName', False)
        params['hotKeyByBarcode'] = convertersConfig.getBool('hotKeyByBarcode', False)
        params['requireSaleRestrict'] = convertersConfig.getBool('requireSaleRestrict', False)
        return ShtrihConverterParameters(**params)
    if converterName in ['atol', 'ATOL']:
        params['measureMapper'] = convertersConfig.getMeasureMapper()
        param = 'charset'
        params[param] = convertersConfig.getString(param, 'cp1251')
        allowedValues = ("cp1251", "utf-8-sig")
        if params[param] not in allowedValues:
            raise AttributeError("Недопустимое значение параметра '%s' для формата '%s'. Возможные значения '%s'"
                                 % (param, converterName, allowedValues))
        params['useMultiplicityQuantityForMeasure'] = convertersConfig.getBool('useMultiplicityQuantityForMeasure',
                                                                               False)
        return AtolConverterParameters(**params)
    if converterName in ['oracle', 'ORACLE']:
        return OracleConverterParameters(**params)
    if converterName in ['smag-ukm', 'smag-ukm4', 'SUPERMAG', 'SUPERMAG4']:
        params['charset'] = convertersConfig.getString('charset', '866')
        params['format'] = convertersConfig.getString('format', 'dat')
        params['defaultRoleCode'] = convertersConfig.getInt('defaultRoleCode', 3)
        params['additionallyRoleCode'] = convertersConfig.getInt('additionallyRoleCode', 2)
        params['usersWithAdditionallyRole'] = convertersConfig.getString('usersWithAdditionallyRole', '').split(',')
        params['relationRolesBy'] = convertersConfig.getString('relationRolesBy', 'name')
        params['substringInAdminName'] = convertersConfig.getString('substringInAdminName', 'Администратор')
        params['catalogBindCode'] = convertersConfig.getString('catalogBindCode', '')
        params['groupBindCode'] = convertersConfig.getString('groupBindCode', '')
        params['group2CatalogMapper'] = convertersConfig.getGroup2CatalogMapper()
        if converterName in ['smag-ukm', 'SUPERMAG']:
            params['setMinPriceIfDiscountRestrictMissing'] = convertersConfig.getBool(
                'setMinPriceIfDiscountRestrictMissing', True)
            return SmagConverterParameters(**params)

        params['discount'] = convertersConfig.getString('discount', 'modern')
        return SmagUkm4ConverterParameters(**params)
    if converterName in ['crystal', 'CRYSTAL']:
        params['visualVerifySG'] = convertersConfig.getString('visualverifysg', '1,2,3')
        params['requireQuantityManualSG'] = convertersConfig.getString('requirequantitymanualsg', '4,5,6')
        params['measureMapper'] = convertersConfig.getParamValue('measuremap', 'шт-1,1007-2')
        if sys.version_info.major == 2 and not isinstance(params['measureMapper'], unicode):
            params['measureMapper'] = unicode(params['measureMapper'], 'utf-8')
        return CrystalConverterParameters(**params)
    if converterName in ['sap', 'SAP']:
        return SapConverterParameters(**params)
    if converterName in ['cif1', 'CIF1']:
        return Cif1ConverterParameters(**params)
    if converterName in ['smag-ukm-xml', 'SUPERMAG_XML']:
        params['measureMapper'] = convertersConfig.getSmagXmlMeasureMapper()
        params['tnvedMapper'] = convertersConfig.getSmagXmlTmcTypeMapper()
        params['quantityOptionsMapper'] = convertersConfig.getSmagXmlQtyOptionsMapper()
        params['tmcRestrictionsMapper'] = convertersConfig.getSmagXmlTmcRestrictionsMapper()
        params['picklistPicturesPath'] = convertersConfig.getString('picklistPicturesPath', '/tmp/picklist/')
        params['cleaningFlagDicts'] = convertersConfig.getString('cleaningFlagDicts', "")
        return SmagXmlConverterParameters(**params)
    return None
